View source: R/plot_punc_model.r
| plot_punc_model | R Documentation |
This function plots data with or without a fit line derived
from the fit_punc_model function.
plot_punc_model(
data,
output_reg,
size = 1,
alpha = 1,
fit = TRUE,
type = c("extant", "serial", "fossil")
)
data |
A data frame with path length in the 1st column, node count in the 2nd, and time in the 3rd |
output_reg |
A list outputted from the |
size |
Size of data point |
alpha |
Transparency of data point (0: transparent; 1: opaque) |
fit |
If |
type |
List of options:
|
This function returns an object of the ggplot class.
Kevin Surya
Freedman and Diaconis (1981); Webster et al. (2003); Pagel et al. (2006); Rambaut et al. (2016)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.